/*********************************************
 * [Code to manipulate navigation show/hide.] *
**********************************************/

// Navigation Bar
const navigation = document.getElementById('main-navigation');

// Burger button
const burger = document.querySelector('button.hamburger');

// Scroll position for show/hide desktop nav
let scrollStatus = window.scrollY;

/**
 * [Reset navbar if window resized.]
**/

window.addEventListener('resize', () => {
    navigation.removeAttribute('style');
    burger.setAttribute('aria-expanded', 'false');
    burger.classList.remove('open');
    navigation.classList.remove('hide');
    navigation.classList.remove('show');
    document.body.removeAttribute('style');
});


/**
 * [Makes navbar hidden when you scroll down and visible when you scroll up on desktop.]
**/
function desktopNavControls() {
    let scrollAmount = window.scrollY;
    if (scrollAmount < scrollStatus || scrollAmount <= 0) {
        // Scrolled up
        navigation.classList.remove('hide');
    } else {
        // Scrolled down
        navigation.classList.add('hide');
    } 
    scrollStatus = scrollAmount;
}


/**
 * [Show navbar using burger button on tablet.]
**/
burger.addEventListener('click', () => {
    navigation.classList.toggle('show');
    burger.classList.toggle('open');
    if (navigation.classList.contains('show')) {
        // Stops user from scrolling while nav is open
        document.body.style.overflow = 'hidden';
        burger.setAttribute('aria-expanded', 'true');
    } else {
        burger.setAttribute('aria-expanded', 'false');
        document.body.style.overflow = 'initial';
    }
});

document.addEventListener('scroll', () => {
    if (window.innerWidth > 601) {
        desktopNavControls();
    }
});